using UnityEngine;
using UnityEngine.Splines;

public class MultiSegmentSpeedSplineFollow : MonoBehaviour
{
    public SplineContainer splineContainer; // Assign your Spline Container
    public float[] segmentDurations; // Duration for each spline segment
    private float t = 0f; // Progress along the spline
    private int currentSegmentIndex = 0; // Current segment index

    // Optional: Reference to an Animator or Animation component
    public Animator objectAnimator; // Assign the Animator if you have one
    public AnimationClip[] segmentAnimations; // Animations for each segment

    void Update()
    {
        if (splineContainer == null || segmentDurations.Length == 0) return;

        // Calculate the current segment's speed based on its duration
        float deltaT = Time.deltaTime / segmentDurations[currentSegmentIndex];

        t += deltaT;

        // Check if we've reached the end of the current segment
        if (t >= 1f)
        {
            // Move to the next segment
            t = 0f; // Reset progress for the next segment
            currentSegmentIndex++;

            // Loop back to the first segment if at the end
            if (currentSegmentIndex >= segmentDurations.Length)
            {
                currentSegmentIndex = 0; // Reset to the first segment
            }

            // Play animation for the new segment if available
            if (objectAnimator != null && currentSegmentIndex < segmentAnimations.Length)
            {
                objectAnimator.Play(segmentAnimations[currentSegmentIndex].name);
            }
        }

        // Calculate the position along the current spline segment
        float segmentT = (float)currentSegmentIndex + t / segmentDurations.Length;
        transform.position = splineContainer.Spline.EvaluatePosition(segmentT);
    }
}
